var hierarchy =
[
    [ "viennacl::ocl::accelerator_tag", "structviennacl_1_1ocl_1_1accelerator__tag.html", null ],
    [ "viennacl::advanced_cuthill_mckee_tag", "classviennacl_1_1advanced__cuthill__mckee__tag.html", null ],
    [ "viennacl::result_of::alignment< T >", "structviennacl_1_1result__of_1_1alignment.html", null ],
    [ "viennacl::linalg::opencl::kernels::ambm_config", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html", null ],
    [ "viennacl::linalg::detail::amg::amg_nonzero_scalar< InternalT, IteratorT, NumericT >", "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__nonzero__scalar.html", null ],
    [ "viennacl::linalg::detail::amg::amg_point", "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__point.html", null ],
    [ "viennacl::linalg::detail::amg::amg_pointvector", "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__pointvector.html", null ],
    [ "viennacl::linalg::amg_precond< MatrixT >", "classviennacl_1_1linalg_1_1amg__precond.html", null ],
    [ "viennacl::linalg::amg_precond< compressed_matrix< NumericT, AlignmentV > >", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html", null ],
    [ "viennacl::linalg::detail::amg::amg_slicing< InternalT1, InternalT2 >", "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__slicing.html", null ],
    [ "viennacl::linalg::detail::amg::amg_sparsematrix< NumericT >", "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html", null ],
    [ "viennacl::linalg::detail::amg::amg_sparsevector< NumericT >", "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html", null ],
    [ "viennacl::linalg::detail::amg::amg_sparsevector< amg_point * >", "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html", null ],
    [ "viennacl::linalg::detail::amg::amg_sparsevector_iterator< InternalT >", "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html", null ],
    [ "viennacl::linalg::detail::amg::amg_tag", "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__tag.html", null ],
    [ "viennacl::backend::cpu_ram::detail::array_deleter< U >", "structviennacl_1_1backend_1_1cpu__ram_1_1detail_1_1array__deleter.html", null ],
    [ "viennacl::linalg::opencl::kernels::asbs_config", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html", null ],
    [ "viennacl::tools::detail::aux", "structviennacl_1_1tools_1_1detail_1_1aux.html", [
      [ "viennacl::tools::detail::auximpl< U, Deleter >", "structviennacl_1_1tools_1_1detail_1_1auximpl.html", null ]
    ] ],
    [ "viennacl::ocl::backend< dummy >", "classviennacl_1_1ocl_1_1backend.html", null ],
    [ "viennacl::basic_range< SizeType, DistanceType >", "classviennacl_1_1basic__range.html", null ],
    [ "viennacl::basic_slice< SizeType, DistanceType >", "classviennacl_1_1basic__slice.html", null ],
    [ "viennacl::linalg::bicgstab_tag", "classviennacl_1_1linalg_1_1bicgstab__tag.html", null ],
    [ "viennacl::device_specific::binary_leaf", "classviennacl_1_1device__specific_1_1binary__leaf.html", [
      [ "viennacl::device_specific::mapped_matrix_column", "classviennacl_1_1device__specific_1_1mapped__matrix__column.html", null ],
      [ "viennacl::device_specific::mapped_matrix_diag", "classviennacl_1_1device__specific_1_1mapped__matrix__diag.html", null ],
      [ "viennacl::device_specific::mapped_matrix_product", "classviennacl_1_1device__specific_1_1mapped__matrix__product.html", null ],
      [ "viennacl::device_specific::mapped_matrix_row", "classviennacl_1_1device__specific_1_1mapped__matrix__row.html", null ],
      [ "viennacl::device_specific::mapped_reduction", "classviennacl_1_1device__specific_1_1mapped__reduction.html", [
        [ "viennacl::device_specific::mapped_row_wise_reduction", "classviennacl_1_1device__specific_1_1mapped__row__wise__reduction.html", null ],
        [ "viennacl::device_specific::mapped_scalar_reduction", "classviennacl_1_1device__specific_1_1mapped__scalar__reduction.html", null ]
      ] ],
      [ "viennacl::device_specific::mapped_trans", "classviennacl_1_1device__specific_1_1mapped__trans.html", null ],
      [ "viennacl::device_specific::mapped_vector_diag", "classviennacl_1_1device__specific_1_1mapped__vector__diag.html", null ]
    ] ],
    [ "viennacl::linalg::opencl::kernels::bisect_kernel< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1bisect__kernel.html", null ],
    [ "viennacl::linalg::block_ilu_precond< MatrixT, ILUTag >", "classviennacl_1_1linalg_1_1block__ilu__precond.html", null ],
    [ "viennacl::linalg::block_ilu_precond< compressed_matrix< NumericT, AlignmentV >, ILUTagT >", "classviennacl_1_1linalg_1_1block__ilu__precond_3_01compressed__matrix_3_01_numeric_t_00_01_align1f935c0ddb2915c5703380de7539023a.html", null ],
    [ "viennacl::linalg::detail::spai::block_matrix", "classviennacl_1_1linalg_1_1detail_1_1spai_1_1block__matrix.html", null ],
    [ "viennacl::linalg::detail::spai::block_vector", "classviennacl_1_1linalg_1_1detail_1_1spai_1_1block__vector.html", null ],
    [ "viennacl::linalg::cg_tag", "classviennacl_1_1linalg_1_1cg__tag.html", null ],
    [ "viennacl::device_specific::char_to_type< C >", "structviennacl_1_1device__specific_1_1char__to__type.html", null ],
    [ "viennacl::tools::CHECK_SCALAR_TEMPLATE_ARGUMENT< T >", "structviennacl_1_1tools_1_1_c_h_e_c_k___s_c_a_l_a_r___t_e_m_p_l_a_t_e___a_r_g_u_m_e_n_t.html", null ],
    [ "viennacl::circulant_matrix< NumericT, AlignmentV >", "classviennacl_1_1circulant__matrix.html", null ],
    [ "viennacl::result_of::cl_type< T >", "structviennacl_1_1result__of_1_1cl__type.html", null ],
    [ "viennacl::linalg::detail::amg::classcomp", "structviennacl_1_1linalg_1_1detail_1_1amg_1_1classcomp.html", null ],
    [ "viennacl::col_iteration", "structviennacl_1_1col__iteration.html", null ],
    [ "viennacl::column_major", "structviennacl_1_1column__major.html", null ],
    [ "viennacl::column_major_tag", "structviennacl_1_1column__major__tag.html", null ],
    [ "viennacl::ocl::command_queue", "classviennacl_1_1ocl_1_1command__queue.html", null ],
    [ "viennacl::linalg::detail::spai::CompareSecond", "structviennacl_1_1linalg_1_1detail_1_1spai_1_1_compare_second.html", null ],
    [ "viennacl::compressed_compressed_matrix< NumericT >", "classviennacl_1_1compressed__compressed__matrix.html", null ],
    [ "viennacl::linalg::opencl::kernels::compressed_compressed_matrix< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__compressed__matrix.html", null ],
    [ "viennacl::compressed_matrix< NumericT, AlignmentV >", "classviennacl_1_1compressed__matrix.html", null ],
    [ "viennacl::linalg::opencl::kernels::compressed_matrix< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__matrix.html", null ],
    [ "viennacl::compressed_matrix< double >", "classviennacl_1_1compressed__matrix.html", null ],
    [ "viennacl::compressed_matrix< float >", "classviennacl_1_1compressed__matrix.html", null ],
    [ "viennacl::compressed_matrix< NumericT >", "classviennacl_1_1compressed__matrix.html", null ],
    [ "viennacl::compressed_matrix< NumericType >", "classviennacl_1_1compressed__matrix.html", null ],
    [ "viennacl::compressed_matrix< ScalarType, MAT_ALIGNMENT >", "classviennacl_1_1compressed__matrix.html", null ],
    [ "viennacl::const_entry_proxy< SCALARTYPE >", "classviennacl_1_1const__entry__proxy.html", null ],
    [ "viennacl::tools::CONST_REMOVER< T >", "structviennacl_1_1tools_1_1_c_o_n_s_t___r_e_m_o_v_e_r.html", null ],
    [ "viennacl::tools::const_sparse_matrix_adapted_iterator< NumericT, SizeT, is_iterator1, is_forward >", "classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html", null ],
    [ "viennacl::tools::const_sparse_matrix_adapter< NumericT, SizeT >", "classviennacl_1_1tools_1_1const__sparse__matrix__adapter.html", [
      [ "viennacl::tools::sparse_matrix_adapter< NumericT, SizeT >", "classviennacl_1_1tools_1_1sparse__matrix__adapter.html", null ]
    ] ],
    [ "viennacl::const_vector_iterator< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1const__vector__iterator.html", null ],
    [ "viennacl::const_vector_iterator< NumericT, AlignmentV >", "classviennacl_1_1const__vector__iterator.html", [
      [ "viennacl::vector_iterator< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1vector__iterator.html", null ]
    ] ],
    [ "viennacl::context", "classviennacl_1_1context.html", null ],
    [ "viennacl::ocl::context", "classviennacl_1_1ocl_1_1context.html", null ],
    [ "viennacl::backend::detail::convert_to_opencl< T >", "structviennacl_1_1backend_1_1detail_1_1convert__to__opencl.html", null ],
    [ "viennacl::linalg::opencl::kernels::coordinate_matrix< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1coordinate__matrix.html", null ],
    [ "viennacl::coordinate_matrix< NumericT, AlignmentV >", "classviennacl_1_1coordinate__matrix.html", null ],
    [ "viennacl::coordinate_matrix< double >", "classviennacl_1_1coordinate__matrix.html", null ],
    [ "viennacl::coordinate_matrix< float >", "classviennacl_1_1coordinate__matrix.html", null ],
    [ "viennacl::tools::detail::count", "classviennacl_1_1tools_1_1detail_1_1count.html", null ],
    [ "viennacl::tools::CPU_SCALAR_TYPE_DEDUCER< T >", "structviennacl_1_1tools_1_1_c_p_u___s_c_a_l_a_r___t_y_p_e___d_e_d_u_c_e_r.html", null ],
    [ "viennacl::ocl::cpu_tag", "structviennacl_1_1ocl_1_1cpu__tag.html", null ],
    [ "viennacl::result_of::cpu_value_type< T >", "structviennacl_1_1result__of_1_1cpu__value__type.html", null ],
    [ "viennacl::backend::cuda::detail::cuda_deleter< U >", "structviennacl_1_1backend_1_1cuda_1_1detail_1_1cuda__deleter.html", null ],
    [ "viennacl::cuthill_mckee_tag", "structviennacl_1_1cuthill__mckee__tag.html", null ],
    [ "viennacl::device_specific::builtin_database::database_type< ParamT >", "classviennacl_1_1device__specific_1_1builtin__database_1_1database__type.html", null ],
    [ "viennacl::tools::detail::default_deleter< U >", "structviennacl_1_1tools_1_1detail_1_1default__deleter.html", null ],
    [ "viennacl::ocl::default_tag", "structviennacl_1_1ocl_1_1default__tag.html", null ],
    [ "dense_matrix< T >", "classdense__matrix.html", null ],
    [ "viennacl::ocl::device", "classviennacl_1_1ocl_1_1device.html", null ],
    [ "viennacl::device_specific::builtin_database::database_type< ParamT >::device_architecture_t", "structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__architecture__t.html", null ],
    [ "viennacl::device_specific::builtin_database::database_type< ParamT >::device_name_t", "structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__name__t.html", null ],
    [ "viennacl::device_specific::builtin_database::database_type< ParamT >::device_type_t", "structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__type__t.html", null ],
    [ "viennacl::ocl::DOUBLE_PRECISION_CHECKER< ScalarType >", "structviennacl_1_1ocl_1_1_d_o_u_b_l_e___p_r_e_c_i_s_i_o_n___c_h_e_c_k_e_r.html", null ],
    [ "viennacl::linalg::opencl::kernels::ell_matrix< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ell__matrix.html", null ],
    [ "viennacl::ell_matrix< NumericT, AlignmentV >", "classviennacl_1_1ell__matrix.html", null ],
    [ "viennacl::ell_matrix< double >", "classviennacl_1_1ell__matrix.html", null ],
    [ "viennacl::ell_matrix< float >", "classviennacl_1_1ell__matrix.html", null ],
    [ "viennacl::enable_if< b, T >", "structviennacl_1_1enable__if.html", null ],
    [ "viennacl::entry_proxy< SCALARTYPE >", "classviennacl_1_1entry__proxy.html", null ],
    [ "viennacl::ocl::error_checker< T >", "structviennacl_1_1ocl_1_1error__checker.html", null ],
    [ "exception", null, [
      [ "viennacl::cuda_not_available_exception", "classviennacl_1_1cuda__not__available__exception.html", null ],
      [ "viennacl::device_specific::generator_not_supported_exception", "classviennacl_1_1device__specific_1_1generator__not__supported__exception.html", null ],
      [ "viennacl::device_specific::template_base::invalid_template_exception", "classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html", null ],
      [ "viennacl::memory_exception", "classviennacl_1_1memory__exception.html", null ],
      [ "viennacl::ocl::build_program_failure", "classviennacl_1_1ocl_1_1build__program__failure.html", null ],
      [ "viennacl::ocl::compiler_not_available", "classviennacl_1_1ocl_1_1compiler__not__available.html", null ],
      [ "viennacl::ocl::device_not_available", "classviennacl_1_1ocl_1_1device__not__available.html", null ],
      [ "viennacl::ocl::device_not_found", "classviennacl_1_1ocl_1_1device__not__found.html", null ],
      [ "viennacl::ocl::double_precision_not_provided_error", "classviennacl_1_1ocl_1_1double__precision__not__provided__error.html", null ],
      [ "viennacl::ocl::image_format_mismatch", "classviennacl_1_1ocl_1_1image__format__mismatch.html", null ],
      [ "viennacl::ocl::image_format_not_supported", "classviennacl_1_1ocl_1_1image__format__not__supported.html", null ],
      [ "viennacl::ocl::invalid_arg_index", "classviennacl_1_1ocl_1_1invalid__arg__index.html", null ],
      [ "viennacl::ocl::invalid_arg_size", "classviennacl_1_1ocl_1_1invalid__arg__size.html", null ],
      [ "viennacl::ocl::invalid_arg_value", "classviennacl_1_1ocl_1_1invalid__arg__value.html", null ],
      [ "viennacl::ocl::invalid_binary", "classviennacl_1_1ocl_1_1invalid__binary.html", null ],
      [ "viennacl::ocl::invalid_buffer_size", "classviennacl_1_1ocl_1_1invalid__buffer__size.html", null ],
      [ "viennacl::ocl::invalid_build_options", "classviennacl_1_1ocl_1_1invalid__build__options.html", null ],
      [ "viennacl::ocl::invalid_command_queue", "classviennacl_1_1ocl_1_1invalid__command__queue.html", null ],
      [ "viennacl::ocl::invalid_context", "classviennacl_1_1ocl_1_1invalid__context.html", null ],
      [ "viennacl::ocl::invalid_device", "classviennacl_1_1ocl_1_1invalid__device.html", null ],
      [ "viennacl::ocl::invalid_device_type", "classviennacl_1_1ocl_1_1invalid__device__type.html", null ],
      [ "viennacl::ocl::invalid_event", "classviennacl_1_1ocl_1_1invalid__event.html", null ],
      [ "viennacl::ocl::invalid_event_wait_list", "classviennacl_1_1ocl_1_1invalid__event__wait__list.html", null ],
      [ "viennacl::ocl::invalid_gl_object", "classviennacl_1_1ocl_1_1invalid__gl__object.html", null ],
      [ "viennacl::ocl::invalid_global_offset", "classviennacl_1_1ocl_1_1invalid__global__offset.html", null ],
      [ "viennacl::ocl::invalid_global_work_size", "classviennacl_1_1ocl_1_1invalid__global__work__size.html", null ],
      [ "viennacl::ocl::invalid_host_ptr", "classviennacl_1_1ocl_1_1invalid__host__ptr.html", null ],
      [ "viennacl::ocl::invalid_image_format_descriptor", "classviennacl_1_1ocl_1_1invalid__image__format__descriptor.html", null ],
      [ "viennacl::ocl::invalid_image_size", "classviennacl_1_1ocl_1_1invalid__image__size.html", null ],
      [ "viennacl::ocl::invalid_kernel", "classviennacl_1_1ocl_1_1invalid__kernel.html", null ],
      [ "viennacl::ocl::invalid_kernel_args", "classviennacl_1_1ocl_1_1invalid__kernel__args.html", null ],
      [ "viennacl::ocl::invalid_kernel_definition", "classviennacl_1_1ocl_1_1invalid__kernel__definition.html", null ],
      [ "viennacl::ocl::invalid_kernel_name", "classviennacl_1_1ocl_1_1invalid__kernel__name.html", null ],
      [ "viennacl::ocl::invalid_mem_object", "classviennacl_1_1ocl_1_1invalid__mem__object.html", null ],
      [ "viennacl::ocl::invalid_mip_level", "classviennacl_1_1ocl_1_1invalid__mip__level.html", null ],
      [ "viennacl::ocl::invalid_operation", "classviennacl_1_1ocl_1_1invalid__operation.html", null ],
      [ "viennacl::ocl::invalid_platform", "classviennacl_1_1ocl_1_1invalid__platform.html", null ],
      [ "viennacl::ocl::invalid_program", "classviennacl_1_1ocl_1_1invalid__program.html", null ],
      [ "viennacl::ocl::invalid_program_executable", "classviennacl_1_1ocl_1_1invalid__program__executable.html", null ],
      [ "viennacl::ocl::invalid_property", "classviennacl_1_1ocl_1_1invalid__property.html", null ],
      [ "viennacl::ocl::invalid_queue_properties", "classviennacl_1_1ocl_1_1invalid__queue__properties.html", null ],
      [ "viennacl::ocl::invalid_sampler", "classviennacl_1_1ocl_1_1invalid__sampler.html", null ],
      [ "viennacl::ocl::invalid_value", "classviennacl_1_1ocl_1_1invalid__value.html", null ],
      [ "viennacl::ocl::invalid_work_dimension", "classviennacl_1_1ocl_1_1invalid__work__dimension.html", null ],
      [ "viennacl::ocl::invalid_work_group_size", "classviennacl_1_1ocl_1_1invalid__work__group__size.html", null ],
      [ "viennacl::ocl::invalid_work_item_size", "classviennacl_1_1ocl_1_1invalid__work__item__size.html", null ],
      [ "viennacl::ocl::map_failure", "classviennacl_1_1ocl_1_1map__failure.html", null ],
      [ "viennacl::ocl::mem_copy_overlap", "classviennacl_1_1ocl_1_1mem__copy__overlap.html", null ],
      [ "viennacl::ocl::mem_object_allocation_failure", "classviennacl_1_1ocl_1_1mem__object__allocation__failure.html", null ],
      [ "viennacl::ocl::out_of_host_memory", "classviennacl_1_1ocl_1_1out__of__host__memory.html", null ],
      [ "viennacl::ocl::out_of_resources", "classviennacl_1_1ocl_1_1out__of__resources.html", null ],
      [ "viennacl::ocl::profiling_info_not_available", "classviennacl_1_1ocl_1_1profiling__info__not__available.html", null ],
      [ "viennacl::ocl::unknown_error", "classviennacl_1_1ocl_1_1unknown__error.html", null ],
      [ "viennacl::scheduler::statement_not_supported_exception", "classviennacl_1_1scheduler_1_1statement__not__supported__exception.html", null ]
    ] ],
    [ "viennacl::device_specific::execution_handler", "classviennacl_1_1device__specific_1_1execution__handler.html", null ],
    [ "viennacl::device_specific::builtin_database::database_type< ParamT >::expression_t", "structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1expression__t.html", null ],
    [ "viennacl::linalg::detail::FastMatrix< SCALARTYPE >", "classviennacl_1_1linalg_1_1detail_1_1_fast_matrix.html", null ],
    [ "viennacl::linalg::opencl::kernels::fft< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1fft.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< T >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< char >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01char_01_4.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< double >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01double_01_4.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< float >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01float_01_4.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< int >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01int_01_4.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< long >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01long_01_4.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< short >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01short_01_4.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< unsigned char >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01char_01_4.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< unsigned int >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01int_01_4.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< unsigned long >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01long_01_4.html", null ],
    [ "viennacl::device_specific::utils::first_letter_of_type< unsigned short >", "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01short_01_4.html", null ],
    [ "viennacl::linalg::fspai_precond< MatrixType >", "classviennacl_1_1linalg_1_1fspai__precond.html", null ],
    [ "viennacl::linalg::fspai_precond< viennacl::compressed_matrix< ScalarType, MAT_ALIGNMENT > >", "classviennacl_1_1linalg_1_1fspai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00e2257d431089a1252a9a2c07955b0dee.html", null ],
    [ "viennacl::linalg::detail::spai::fspai_tag", "classviennacl_1_1linalg_1_1detail_1_1spai_1_1fspai__tag.html", null ],
    [ "viennacl::gibbs_poole_stockmeyer_tag", "structviennacl_1_1gibbs__poole__stockmeyer__tag.html", null ],
    [ "viennacl::linalg::gmres_tag", "classviennacl_1_1linalg_1_1gmres__tag.html", null ],
    [ "viennacl::ocl::gpu_tag", "structviennacl_1_1ocl_1_1gpu__tag.html", null ],
    [ "viennacl::ocl::handle< OCL_TYPE >", "classviennacl_1_1ocl_1_1handle.html", null ],
    [ "viennacl::ocl::handle< cl_command_queue >", "classviennacl_1_1ocl_1_1handle.html", null ],
    [ "viennacl::ocl::handle< cl_context >", "classviennacl_1_1ocl_1_1handle.html", null ],
    [ "viennacl::ocl::handle< cl_kernel >", "classviennacl_1_1ocl_1_1handle.html", null ],
    [ "viennacl::ocl::handle< cl_mem >", "classviennacl_1_1ocl_1_1handle.html", null ],
    [ "viennacl::ocl::handle< cl_program >", "classviennacl_1_1ocl_1_1handle.html", null ],
    [ "viennacl::device_specific::utils::handle_fun", "structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html", null ],
    [ "viennacl::ocl::handle_inc_dec_helper< OCL_TYPE >", "classviennacl_1_1ocl_1_1handle__inc__dec__helper.html", null ],
    [ "viennacl::hankel_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1hankel__matrix.html", null ],
    [ "viennacl::linalg::opencl::kernels::hyb_matrix< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1hyb__matrix.html", null ],
    [ "viennacl::hyb_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1hyb__matrix.html", null ],
    [ "viennacl::hyb_matrix< double >", "classviennacl_1_1hyb__matrix.html", null ],
    [ "viennacl::hyb_matrix< float >", "classviennacl_1_1hyb__matrix.html", null ],
    [ "viennacl::linalg::ichol0_precond< MatrixT >", "classviennacl_1_1linalg_1_1ichol0__precond.html", null ],
    [ "viennacl::linalg::ichol0_precond< compressed_matrix< NumericT, AlignmentV > >", "classviennacl_1_1linalg_1_1ichol0__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html", null ],
    [ "viennacl::linalg::ichol0_tag", "classviennacl_1_1linalg_1_1ichol0__tag.html", null ],
    [ "viennacl::linalg::opencl::kernels::ilu< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ilu.html", null ],
    [ "viennacl::linalg::ilu0_precond< MatrixT >", "classviennacl_1_1linalg_1_1ilu0__precond.html", null ],
    [ "viennacl::linalg::ilu0_precond< viennacl::compressed_matrix< NumericT, AlignmentV > >", "classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html", null ],
    [ "viennacl::linalg::ilu0_tag", "classviennacl_1_1linalg_1_1ilu0__tag.html", null ],
    [ "viennacl::linalg::detail::ilu_vector_range< VectorT, NumericT, SizeT >", "classviennacl_1_1linalg_1_1detail_1_1ilu__vector__range.html", null ],
    [ "viennacl::linalg::ilut_precond< MatrixT >", "classviennacl_1_1linalg_1_1ilut__precond.html", null ],
    [ "viennacl::linalg::ilut_precond< viennacl::compressed_matrix< NumericT, AlignmentV > >", "classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html", null ],
    [ "viennacl::linalg::ilut_tag", "classviennacl_1_1linalg_1_1ilut__tag.html", null ],
    [ "viennacl::implicit_matrix_base< NumericT >", "classviennacl_1_1implicit__matrix__base.html", [
      [ "viennacl::identity_matrix< NumericT >", "classviennacl_1_1identity__matrix.html", null ],
      [ "viennacl::scalar_matrix< NumericT >", "classviennacl_1_1scalar__matrix.html", null ],
      [ "viennacl::zero_matrix< NumericT >", "classviennacl_1_1zero__matrix.html", null ]
    ] ],
    [ "viennacl::implicit_matrix_base< char >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_matrix_base< double >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_matrix_base< float >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_matrix_base< int >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_matrix_base< long >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_matrix_base< short >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_matrix_base< unsigned char >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_matrix_base< unsigned int >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_matrix_base< unsigned long >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_matrix_base< unsigned short >", "classviennacl_1_1implicit__matrix__base.html", null ],
    [ "viennacl::implicit_vector_base< NumericT >", "classviennacl_1_1implicit__vector__base.html", [
      [ "viennacl::scalar_vector< NumericT >", "structviennacl_1_1scalar__vector.html", [
        [ "viennacl::zero_vector< NumericT >", "structviennacl_1_1zero__vector.html", null ]
      ] ],
      [ "viennacl::unit_vector< NumericT >", "structviennacl_1_1unit__vector.html", null ]
    ] ],
    [ "viennacl::implicit_vector_base< char >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::implicit_vector_base< double >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::implicit_vector_base< float >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::implicit_vector_base< int >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::implicit_vector_base< long >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::implicit_vector_base< short >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::implicit_vector_base< unsigned char >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::implicit_vector_base< unsigned int >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::implicit_vector_base< unsigned long >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::implicit_vector_base< unsigned short >", "classviennacl_1_1implicit__vector__base.html", null ],
    [ "viennacl::device_specific::index_tuple", "structviennacl_1_1device__specific_1_1index__tuple.html", null ],
    [ "viennacl::linalg::detail::InputData< NumericT >", "structviennacl_1_1linalg_1_1detail_1_1_input_data.html", null ],
    [ "viennacl::device_specific::utils::internal_size1_fun", "structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html", null ],
    [ "viennacl::device_specific::utils::internal_size2_fun", "structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html", null ],
    [ "viennacl::device_specific::utils::internal_size_fun", "structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html", null ],
    [ "viennacl::is_addition< T >", "structviennacl_1_1is__addition.html", null ],
    [ "viennacl::is_any_dense_matrix< T >", "structviennacl_1_1is__any__dense__matrix.html", null ],
    [ "viennacl::is_any_dense_structured_matrix< T >", "structviennacl_1_1is__any__dense__structured__matrix.html", null ],
    [ "viennacl::is_any_scalar< T >", "structviennacl_1_1is__any__scalar.html", null ],
    [ "viennacl::is_any_sparse_matrix< T >", "structviennacl_1_1is__any__sparse__matrix.html", null ],
    [ "viennacl::is_any_vector< T >", "structviennacl_1_1is__any__vector.html", null ],
    [ "viennacl::is_circulant_matrix< T >", "structviennacl_1_1is__circulant__matrix.html", null ],
    [ "viennacl::is_compressed_matrix< T >", "structviennacl_1_1is__compressed__matrix.html", null ],
    [ "viennacl::is_coordinate_matrix< T >", "structviennacl_1_1is__coordinate__matrix.html", null ],
    [ "viennacl::is_cpu_scalar< T >", "structviennacl_1_1is__cpu__scalar.html", null ],
    [ "viennacl::is_division< T >", "structviennacl_1_1is__division.html", null ],
    [ "viennacl::is_eigen< Tag >", "structviennacl_1_1is__eigen.html", null ],
    [ "viennacl::is_ell_matrix< T >", "structviennacl_1_1is__ell__matrix.html", null ],
    [ "viennacl::is_flip_sign_scalar< T >", "structviennacl_1_1is__flip__sign__scalar.html", null ],
    [ "viennacl::is_hankel_matrix< T >", "structviennacl_1_1is__hankel__matrix.html", null ],
    [ "viennacl::is_hyb_matrix< T >", "structviennacl_1_1is__hyb__matrix.html", null ],
    [ "viennacl::is_mtl4< Tag >", "structviennacl_1_1is__mtl4.html", null ],
    [ "viennacl::is_primitive_type< T >", "structviennacl_1_1is__primitive__type.html", null ],
    [ "viennacl::is_product< T >", "structviennacl_1_1is__product.html", null ],
    [ "viennacl::is_row_major< T >", "structviennacl_1_1is__row__major.html", null ],
    [ "viennacl::device_specific::utils::is_same_type< T, U >", "structviennacl_1_1device__specific_1_1utils_1_1is__same__type.html", null ],
    [ "viennacl::device_specific::utils::is_same_type< T, T >", "structviennacl_1_1device__specific_1_1utils_1_1is__same__type_3_01_t_00_01_t_01_4.html", null ],
    [ "viennacl::is_scalar< T >", "structviennacl_1_1is__scalar.html", null ],
    [ "viennacl::is_sliced_ell_matrix< T >", "structviennacl_1_1is__sliced__ell__matrix.html", null ],
    [ "viennacl::is_stl< Tag >", "structviennacl_1_1is__stl.html", null ],
    [ "viennacl::is_subtraction< T >", "structviennacl_1_1is__subtraction.html", null ],
    [ "viennacl::is_toeplitz_matrix< T >", "structviennacl_1_1is__toeplitz__matrix.html", null ],
    [ "viennacl::is_ublas< Tag >", "structviennacl_1_1is__ublas.html", null ],
    [ "viennacl::is_vandermonde_matrix< T >", "structviennacl_1_1is__vandermonde__matrix.html", null ],
    [ "viennacl::is_viennacl< Tag >", "structviennacl_1_1is__viennacl.html", null ],
    [ "viennacl::linalg::opencl::kernels::iterative< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1iterative.html", null ],
    [ "viennacl::linalg::jacobi_precond< MatrixT, is_viennacl >", "classviennacl_1_1linalg_1_1jacobi__precond.html", null ],
    [ "viennacl::linalg::jacobi_precond< MatrixT, true >", "classviennacl_1_1linalg_1_1jacobi__precond_3_01_matrix_t_00_01true_01_4.html", null ],
    [ "viennacl::linalg::jacobi_tag", "classviennacl_1_1linalg_1_1jacobi__tag.html", null ],
    [ "viennacl::ocl::kernel", "classviennacl_1_1ocl_1_1kernel.html", null ],
    [ "viennacl::linalg::lanczos_tag", "classviennacl_1_1linalg_1_1lanczos__tag.html", null ],
    [ "viennacl::device_specific::lazy_program_compiler", "classviennacl_1_1device__specific_1_1lazy__program__compiler.html", null ],
    [ "viennacl::device_specific::utils::leading_start", "structviennacl_1_1device__specific_1_1utils_1_1leading__start.html", null ],
    [ "viennacl::device_specific::utils::leading_stride", "structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html", null ],
    [ "viennacl::scheduler::lhs_rhs_element", "structviennacl_1_1scheduler_1_1lhs__rhs__element.html", null ],
    [ "viennacl::ocl::local_mem", "classviennacl_1_1ocl_1_1local__mem.html", null ],
    [ "viennacl::device_specific::template_base::loop_body_base", "structviennacl_1_1device__specific_1_1template__base_1_1loop__body__base.html", null ],
    [ "viennacl::linalg::lower_tag", "structviennacl_1_1linalg_1_1lower__tag.html", null ],
    [ "viennacl::device_specific::mapped_object", "classviennacl_1_1device__specific_1_1mapped__object.html", [
      [ "viennacl::device_specific::mapped_handle", "classviennacl_1_1device__specific_1_1mapped__handle.html", [
        [ "viennacl::device_specific::mapped_buffer", "classviennacl_1_1device__specific_1_1mapped__buffer.html", [
          [ "viennacl::device_specific::mapped_matrix", "classviennacl_1_1device__specific_1_1mapped__matrix.html", null ],
          [ "viennacl::device_specific::mapped_vector", "classviennacl_1_1device__specific_1_1mapped__vector.html", null ]
        ] ],
        [ "viennacl::device_specific::mapped_scalar", "classviennacl_1_1device__specific_1_1mapped__scalar.html", null ]
      ] ],
      [ "viennacl::device_specific::mapped_host_scalar", "classviennacl_1_1device__specific_1_1mapped__host__scalar.html", null ],
      [ "viennacl::device_specific::mapped_implicit_matrix", "classviennacl_1_1device__specific_1_1mapped__implicit__matrix.html", null ],
      [ "viennacl::device_specific::mapped_implicit_vector", "classviennacl_1_1device__specific_1_1mapped__implicit__vector.html", null ],
      [ "viennacl::device_specific::mapped_matrix_column", "classviennacl_1_1device__specific_1_1mapped__matrix__column.html", null ],
      [ "viennacl::device_specific::mapped_matrix_diag", "classviennacl_1_1device__specific_1_1mapped__matrix__diag.html", null ],
      [ "viennacl::device_specific::mapped_matrix_product", "classviennacl_1_1device__specific_1_1mapped__matrix__product.html", null ],
      [ "viennacl::device_specific::mapped_matrix_row", "classviennacl_1_1device__specific_1_1mapped__matrix__row.html", null ],
      [ "viennacl::device_specific::mapped_reduction", "classviennacl_1_1device__specific_1_1mapped__reduction.html", null ],
      [ "viennacl::device_specific::mapped_trans", "classviennacl_1_1device__specific_1_1mapped__trans.html", null ],
      [ "viennacl::device_specific::mapped_vector_diag", "classviennacl_1_1device__specific_1_1mapped__vector__diag.html", null ]
    ] ],
    [ "viennacl::linalg::cuda::mat_mult_matrix_index< LayoutT >", "structviennacl_1_1linalg_1_1cuda_1_1mat__mult__matrix__index.html", null ],
    [ "viennacl::linalg::opencl::kernels::matrix< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html", null ],
    [ "viennacl::linalg::host_based::detail::matrix_array_wrapper< NumericT, LayoutT, is_transposed >", "classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html", null ],
    [ "viennacl::matrix_base< NumericT, SizeT, DistanceT >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< char >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< double >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< float >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< int >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< long >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< MatrixType::cpu_value_type >", "classviennacl_1_1matrix__base.html", [
      [ "viennacl::matrix_range< MatrixType >", "classviennacl_1_1matrix__range.html", null ],
      [ "viennacl::matrix_range< matrix_range< MatrixType > >", "classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html", null ],
      [ "viennacl::matrix_slice< MatrixType >", "classviennacl_1_1matrix__slice.html", null ],
      [ "viennacl::matrix_slice< matrix_range< MatrixType > >", "classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html", null ]
    ] ],
    [ "viennacl::matrix_base< NumericT >", "classviennacl_1_1matrix__base.html", [
      [ "viennacl::matrix< SCALARTYPE, F, ALIGNMENT >", "classviennacl_1_1matrix.html", null ]
    ] ],
    [ "viennacl::matrix_base< short >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< unsigned char >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< unsigned int >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< unsigned long >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::matrix_base< unsigned short >", "classviennacl_1_1matrix__base.html", null ],
    [ "viennacl::linalg::opencl::kernels::matrix_element< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__element.html", null ],
    [ "viennacl::matrix_expression< LHS, RHS, OP >", "classviennacl_1_1matrix__expression.html", null ],
    [ "viennacl::matrix_iterator< ROWCOL, MATRIXTYPE >", "classviennacl_1_1matrix__iterator.html", null ],
    [ "viennacl::tools::MATRIX_ITERATOR_INCREMENTER< ROWCOL, MATRIXTYPE >", "structviennacl_1_1tools_1_1_m_a_t_r_i_x___i_t_e_r_a_t_o_r___i_n_c_r_e_m_e_n_t_e_r.html", null ],
    [ "viennacl::linalg::opencl::kernels::matrix_legacy< NumericT, LayoutT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__legacy.html", null ],
    [ "matrix_maker< UBlasType, F >", "structmatrix__maker.html", null ],
    [ "matrix_maker< boost::numeric::ublas::matrix< T >, F >", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4.html", null ],
    [ "matrix_maker< boost::numeric::ublas::matrix_range< MatrixT >, F >", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__range_3_01_matrix_t_01_4_00_01_f_01_4.html", null ],
    [ "matrix_maker< boost::numeric::ublas::matrix_slice< MatrixT >, F >", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html", null ],
    [ "viennacl::linalg::opencl::kernels::matrix_prod< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__prod.html", null ],
    [ "viennacl::tools::MATRIX_SIZE_DEDUCER< LHS, RHS, OP >", "structviennacl_1_1tools_1_1_m_a_t_r_i_x___s_i_z_e___d_e_d_u_c_e_r.html", null ],
    [ "viennacl::linalg::opencl::kernels::matrix_solve< NumericT, LayoutT1, LayoutT2 >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__solve.html", null ],
    [ "viennacl::backend::mem_handle", "classviennacl_1_1backend_1_1mem__handle.html", null ],
    [ "viennacl::linalg::mixed_precision_cg_tag", "classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html", null ],
    [ "viennacl::device_specific::mapped_object::MorphBase", "structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base.html", [
      [ "viennacl::device_specific::mapped_object::MorphBase1D", "structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base1_d.html", null ],
      [ "viennacl::device_specific::mapped_object::MorphBase2D", "structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base2_d.html", null ]
    ] ],
    [ "my_inserter< MatrixType >", "classmy__inserter.html", null ],
    [ "viennacl::linalg::opencl::kernels::nmf< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1nmf.html", null ],
    [ "viennacl::linalg::nmf_config", "classviennacl_1_1linalg_1_1nmf__config.html", null ],
    [ "viennacl::linalg::no_precond", "classviennacl_1_1linalg_1_1no__precond.html", null ],
    [ "viennacl::device_specific::mapped_object::node_info", "structviennacl_1_1device__specific_1_1mapped__object_1_1node__info.html", null ],
    [ "viennacl::scheduler::result_of::num_nodes< T >", "structviennacl_1_1scheduler_1_1result__of_1_1num__nodes.html", null ],
    [ "viennacl::scheduler::result_of::num_nodes< const matrix_expression< LHS, RHS, OP > >", "structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01const_01matrix__expression_3_01_l_h_011069f9bf48127b37197927d0585554.html", null ],
    [ "viennacl::scheduler::result_of::num_nodes< const scalar_expression< LHS, RHS, OP > >", "structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01const_01scalar__expression_3_01_l_h_9d9a43e9a0aea2e2e741ea6a9166750d.html", null ],
    [ "viennacl::scheduler::result_of::num_nodes< const vector_expression< LHS, RHS, OP > >", "structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01const_01vector__expression_3_01_l_h_db8a7bb6e522575b18239d7526a98bfc.html", null ],
    [ "viennacl::scheduler::result_of::num_nodes< matrix_expression< LHS, RHS, OP > >", "structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01matrix__expression_3_01_l_h_s_00_01_r_h_s_00_01_o_p_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::num_nodes< scalar_expression< LHS, RHS, OP > >", "structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01_o_p_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::num_nodes< vector_expression< LHS, RHS, OP > >", "structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01vector__expression_3_01_l_h_s_00_01_r_h_s_00_01_o_p_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::numeric_type_id< T >", "structviennacl_1_1scheduler_1_1result__of_1_1numeric__type__id.html", null ],
    [ "viennacl::one_vector< SCALARTYPE >", "structviennacl_1_1one__vector.html", null ],
    [ "viennacl::op_abs", "structviennacl_1_1op__abs.html", null ],
    [ "viennacl::op_acos", "structviennacl_1_1op__acos.html", null ],
    [ "viennacl::op_add", "structviennacl_1_1op__add.html", null ],
    [ "viennacl::linalg::detail::op_applier< OpT >", "structviennacl_1_1linalg_1_1detail_1_1op__applier.html", null ],
    [ "viennacl::op_argmax", "structviennacl_1_1op__argmax.html", null ],
    [ "viennacl::op_argmin", "structviennacl_1_1op__argmin.html", null ],
    [ "viennacl::op_asin", "structviennacl_1_1op__asin.html", null ],
    [ "op_assign", "structop__assign.html", null ],
    [ "viennacl::op_assign", "structviennacl_1_1op__assign.html", null ],
    [ "viennacl::op_atan", "structviennacl_1_1op__atan.html", null ],
    [ "viennacl::op_atan2", "structviennacl_1_1op__atan2.html", null ],
    [ "viennacl::op_ceil", "structviennacl_1_1op__ceil.html", null ],
    [ "viennacl::op_column", "structviennacl_1_1op__column.html", null ],
    [ "viennacl::op_cos", "structviennacl_1_1op__cos.html", null ],
    [ "viennacl::op_cosh", "structviennacl_1_1op__cosh.html", null ],
    [ "viennacl::op_div", "structviennacl_1_1op__div.html", null ],
    [ "viennacl::scheduler::op_element", "structviennacl_1_1scheduler_1_1op__element.html", null ],
    [ "viennacl::op_element_binary< OP >", "structviennacl_1_1op__element__binary.html", null ],
    [ "viennacl::op_element_cast< OP >", "structviennacl_1_1op__element__cast.html", null ],
    [ "viennacl::op_element_unary< OP >", "structviennacl_1_1op__element__unary.html", null ],
    [ "viennacl::op_eq", "structviennacl_1_1op__eq.html", null ],
    [ "viennacl::linalg::detail::op_executor< A, OP, T >", "structviennacl_1_1linalg_1_1detail_1_1op__executor.html", null ],
    [ "viennacl::op_exp", "structviennacl_1_1op__exp.html", null ],
    [ "viennacl::op_fabs", "structviennacl_1_1op__fabs.html", null ],
    [ "viennacl::op_fdim", "structviennacl_1_1op__fdim.html", null ],
    [ "viennacl::op_flip_sign", "structviennacl_1_1op__flip__sign.html", null ],
    [ "viennacl::op_floor", "structviennacl_1_1op__floor.html", null ],
    [ "viennacl::op_fmax", "structviennacl_1_1op__fmax.html", null ],
    [ "viennacl::op_fmin", "structviennacl_1_1op__fmin.html", null ],
    [ "viennacl::op_fmod", "structviennacl_1_1op__fmod.html", null ],
    [ "viennacl::op_geq", "structviennacl_1_1op__geq.html", null ],
    [ "viennacl::op_greater", "structviennacl_1_1op__greater.html", null ],
    [ "viennacl::op_inner_prod", "structviennacl_1_1op__inner__prod.html", null ],
    [ "viennacl::op_inplace_add", "structviennacl_1_1op__inplace__add.html", null ],
    [ "viennacl::op_inplace_sub", "structviennacl_1_1op__inplace__sub.html", null ],
    [ "viennacl::op_leq", "structviennacl_1_1op__leq.html", null ],
    [ "viennacl::op_less", "structviennacl_1_1op__less.html", null ],
    [ "viennacl::op_log", "structviennacl_1_1op__log.html", null ],
    [ "viennacl::op_log10", "structviennacl_1_1op__log10.html", null ],
    [ "viennacl::op_mat_mat_prod", "structviennacl_1_1op__mat__mat__prod.html", null ],
    [ "viennacl::op_matrix_diag", "structviennacl_1_1op__matrix__diag.html", null ],
    [ "viennacl::op_max", "structviennacl_1_1op__max.html", null ],
    [ "viennacl::op_min", "structviennacl_1_1op__min.html", null ],
    [ "op_minus_assign", "structop__minus__assign.html", null ],
    [ "viennacl::op_mult", "structviennacl_1_1op__mult.html", null ],
    [ "viennacl::op_neq", "structviennacl_1_1op__neq.html", null ],
    [ "viennacl::op_norm_1", "structviennacl_1_1op__norm__1.html", null ],
    [ "viennacl::op_norm_2", "structviennacl_1_1op__norm__2.html", null ],
    [ "viennacl::op_norm_frobenius", "structviennacl_1_1op__norm__frobenius.html", null ],
    [ "viennacl::op_norm_inf", "structviennacl_1_1op__norm__inf.html", null ],
    [ "op_plus_assign", "structop__plus__assign.html", null ],
    [ "viennacl::op_pow", "structviennacl_1_1op__pow.html", null ],
    [ "viennacl::op_prod", "structviennacl_1_1op__prod.html", null ],
    [ "viennacl::op_reduce_columns< T >", "structviennacl_1_1op__reduce__columns.html", null ],
    [ "viennacl::op_reduce_rows< T >", "structviennacl_1_1op__reduce__rows.html", null ],
    [ "viennacl::op_reduce_vector< T >", "structviennacl_1_1op__reduce__vector.html", null ],
    [ "viennacl::op_row", "structviennacl_1_1op__row.html", null ],
    [ "viennacl::op_sin", "structviennacl_1_1op__sin.html", null ],
    [ "viennacl::op_sinh", "structviennacl_1_1op__sinh.html", null ],
    [ "viennacl::op_sqrt", "structviennacl_1_1op__sqrt.html", null ],
    [ "viennacl::op_sub", "structviennacl_1_1op__sub.html", null ],
    [ "viennacl::op_tan", "structviennacl_1_1op__tan.html", null ],
    [ "viennacl::op_tanh", "structviennacl_1_1op__tanh.html", null ],
    [ "viennacl::op_trans", "structviennacl_1_1op__trans.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< T >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_add >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__add_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_assign >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__assign_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_column >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__column_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_div >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__div_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_argmax > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__argmax_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_argmin > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__argmin_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_div > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__div_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_eq > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__eq_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_fmax > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__fmax_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_fmin > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__fmin_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_geq > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__geq_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_greater > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__greater_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_leq > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__leq_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_less > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__less_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_neq > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__neq_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_pow > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__pow_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_binary< op_prod > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__prod_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< char > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01char_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< double > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01double_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< float > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01float_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< int > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01int_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< long > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01long_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< short > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01short_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< unsigned char > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01char_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< unsigned int > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01int_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< unsigned long > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01long_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_cast< unsigned short > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01short_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_abs > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__abs_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_acos > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__acos_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_asin > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__asin_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_atan > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__atan_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_ceil > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__ceil_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_cos > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__cos_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_cosh > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__cosh_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_exp > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__exp_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_fabs > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__fabs_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_floor > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__floor_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_log > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__log_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_log10 > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__log10_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_sin > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__sin_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_sinh > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__sinh_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_sqrt > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__sqrt_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_tan > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__tan_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_element_unary< op_tanh > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__tanh_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_flip_sign >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__flip__sign_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_inner_prod >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inner__prod_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_inplace_add >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inplace__add_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_inplace_sub >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inplace__sub_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_mat_mat_prod >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__mat__mat__prod_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_matrix_diag >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__matrix__diag_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_max >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__max_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_min >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__min_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_mult >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__mult_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_norm_1 >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__1_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_norm_2 >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__2_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_norm_inf >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__inf_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_prod >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__prod_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_reduce_columns< OP > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__columns_3_01_o_p_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_reduce_rows< OP > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__rows_3_01_o_p_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_reduce_vector< OP > >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__vector_3_01_o_p_01_4_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_row >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__row_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_sub >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__sub_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_trans >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__trans_01_4.html", null ],
    [ "viennacl::scheduler::result_of::op_type_info< op_vector_diag >", "structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__vector__diag_01_4.html", null ],
    [ "viennacl::op_vector_diag", "structviennacl_1_1op__vector__diag.html", null ],
    [ "ostream", null, [
      [ "viennacl::device_specific::utils::kernel_generation_stream", "classviennacl_1_1device__specific_1_1utils_1_1kernel__generation__stream.html", null ]
    ] ],
    [ "viennacl::ocl::packed_cl_uint", "structviennacl_1_1ocl_1_1packed__cl__uint.html", null ],
    [ "viennacl::device_specific::template_base::parameters_type", "structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html", [
      [ "viennacl::device_specific::matrix_axpy_parameters_type", "classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html", null ],
      [ "viennacl::device_specific::matrix_product_parameters", "structviennacl_1_1device__specific_1_1matrix__product__parameters.html", null ],
      [ "viennacl::device_specific::reduction_parameters", "structviennacl_1_1device__specific_1_1reduction__parameters.html", null ],
      [ "viennacl::device_specific::row_wise_reduction_parameters", "structviennacl_1_1device__specific_1_1row__wise__reduction__parameters.html", null ],
      [ "viennacl::device_specific::vector_axpy_parameters", "classviennacl_1_1device__specific_1_1vector__axpy__parameters.html", null ]
    ] ],
    [ "viennacl::ocl::platform", "classviennacl_1_1ocl_1_1platform.html", null ],
    [ "viennacl::linalg::power_iter_tag", "classviennacl_1_1linalg_1_1power__iter__tag.html", null ],
    [ "viennacl::ocl::program", "classviennacl_1_1ocl_1_1program.html", null ],
    [ "viennacl::linalg::detail::ResultDataLarge< NumericT >", "structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html", null ],
    [ "viennacl::linalg::detail::ResultDataSmall< NumericT >", "structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html", null ],
    [ "viennacl::row_iteration", "structviennacl_1_1row__iteration.html", null ],
    [ "viennacl::row_major", "structviennacl_1_1row__major.html", null ],
    [ "viennacl::device_specific::utils::row_major_fun", "structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html", null ],
    [ "viennacl::row_major_tag", "structviennacl_1_1row__major__tag.html", null ],
    [ "viennacl::linalg::row_scaling< MatrixType, is_viennacl >", "classviennacl_1_1linalg_1_1row__scaling.html", null ],
    [ "viennacl::linalg::row_scaling< MatrixType, true >", "classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html", null ],
    [ "viennacl::linalg::row_scaling_tag", "classviennacl_1_1linalg_1_1row__scaling__tag.html", null ],
    [ "viennacl::linalg::opencl::kernels::row_wise_reduction< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1row__wise__reduction.html", null ],
    [ "viennacl::linalg::opencl::kernels::scalar< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html", null ],
    [ "viennacl::scalar< TYPE >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< char >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< double >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< float >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< int >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< long >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< short >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< unsigned char >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< unsigned int >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< unsigned long >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar< unsigned short >", "classviennacl_1_1scalar.html", null ],
    [ "viennacl::scalar_expression< LHS, RHS, OP >", "classviennacl_1_1scalar__expression.html", null ],
    [ "viennacl::scalar_expression< LHS, RHS, op_inner_prod >", "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__inner__prod_01_4.html", null ],
    [ "viennacl::scalar_expression< LHS, RHS, op_max >", "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__max_01_4.html", null ],
    [ "viennacl::scalar_expression< LHS, RHS, op_min >", "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__min_01_4.html", null ],
    [ "viennacl::scalar_expression< LHS, RHS, op_norm_1 >", "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__1_01_4.html", null ],
    [ "viennacl::scalar_expression< LHS, RHS, op_norm_2 >", "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html", null ],
    [ "viennacl::scalar_expression< LHS, RHS, op_norm_frobenius >", "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html", null ],
    [ "viennacl::scalar_expression< LHS, RHS, op_norm_inf >", "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html", null ],
    [ "viennacl::device_specific::utils::scalartype_size_fun", "structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html", null ],
    [ "viennacl::tools::detail::sha1", "classviennacl_1_1tools_1_1detail_1_1sha1.html", null ],
    [ "viennacl::tools::shared_ptr< T >", "classviennacl_1_1tools_1_1shared__ptr.html", null ],
    [ "viennacl::tools::shared_ptr< char >", "classviennacl_1_1tools_1_1shared__ptr.html", null ],
    [ "viennacl::device_specific::utils::size1_fun", "structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html", null ],
    [ "viennacl::device_specific::utils::size2_fun", "structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html", null ],
    [ "viennacl::device_specific::utils::size_fun", "structviennacl_1_1device__specific_1_1utils_1_1size__fun.html", null ],
    [ "viennacl::result_of::size_type< T >", "structviennacl_1_1result__of_1_1size__type.html", null ],
    [ "viennacl::sliced_ell_matrix< ScalarT, IndexT >", "classviennacl_1_1sliced__ell__matrix.html", null ],
    [ "viennacl::linalg::opencl::kernels::sliced_ell_matrix< NumericT, IndexT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix.html", null ],
    [ "viennacl::linalg::opencl::kernels::sliced_ell_matrix< NumericT, unsigned int >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix_3_01_numeric_t_00_01unsigned_01int_01_4.html", null ],
    [ "viennacl::linalg::opencl::kernels::spai< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1spai.html", null ],
    [ "viennacl::linalg::spai_precond< MatrixType >", "classviennacl_1_1linalg_1_1spai__precond.html", null ],
    [ "viennacl::linalg::spai_precond< viennacl::compressed_matrix< ScalarType, MAT_ALIGNMENT > >", "classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html", null ],
    [ "viennacl::linalg::detail::spai::spai_tag", "classviennacl_1_1linalg_1_1detail_1_1spai_1_1spai__tag.html", null ],
    [ "viennacl::tools::sparse_matrix_adapted_iterator< NumericT, SizeT, is_iterator1 >", "classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html", null ],
    [ "viennacl::linalg::detail::spai::sparse_vector< NumericT >", "classviennacl_1_1linalg_1_1detail_1_1spai_1_1sparse__vector.html", null ],
    [ "viennacl::device_specific::utils::start1_fun", "structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html", null ],
    [ "viennacl::device_specific::utils::start2_fun", "structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html", null ],
    [ "viennacl::scheduler::statement", "classviennacl_1_1scheduler_1_1statement.html", null ],
    [ "viennacl::scheduler::statement_node", "structviennacl_1_1scheduler_1_1statement__node.html", null ],
    [ "viennacl::device_specific::statements_container", "classviennacl_1_1device__specific_1_1statements__container.html", null ],
    [ "viennacl::device_specific::utils::stride1_fun", "structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html", null ],
    [ "viennacl::device_specific::utils::stride2_fun", "structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html", null ],
    [ "viennacl::device_specific::utils::stride_fun", "structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html", null ],
    [ "viennacl::linalg::opencl::kernels::svd< NumericT, MatrixLayout >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1svd.html", null ],
    [ "viennacl::device_specific::symbolic_binder", "classviennacl_1_1device__specific_1_1symbolic__binder.html", [
      [ "viennacl::device_specific::bind_all_unique", "classviennacl_1_1device__specific_1_1bind__all__unique.html", null ],
      [ "viennacl::device_specific::bind_to_handle", "classviennacl_1_1device__specific_1_1bind__to__handle.html", null ]
    ] ],
    [ "viennacl::tag_eigen", "structviennacl_1_1tag__eigen.html", null ],
    [ "viennacl::tag_mtl4", "structviennacl_1_1tag__mtl4.html", null ],
    [ "viennacl::tag_none", "structviennacl_1_1tag__none.html", null ],
    [ "viennacl::traits::tag_of< T, Active >", "structviennacl_1_1traits_1_1tag__of.html", null ],
    [ "viennacl::tag_stl", "structviennacl_1_1tag__stl.html", null ],
    [ "viennacl::tag_ublas", "structviennacl_1_1tag__ublas.html", null ],
    [ "viennacl::tag_viennacl", "structviennacl_1_1tag__viennacl.html", null ],
    [ "viennacl::device_specific::template_base", "classviennacl_1_1device__specific_1_1template__base.html", [
      [ "viennacl::device_specific::template_base_impl< matrix_axpy_template, matrix_axpy_parameters_type >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
        [ "viennacl::device_specific::matrix_axpy_template", "classviennacl_1_1device__specific_1_1matrix__axpy__template.html", null ]
      ] ],
      [ "viennacl::device_specific::template_base_impl< matrix_product_template, matrix_product_parameters >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
        [ "viennacl::device_specific::matrix_product_template", "classviennacl_1_1device__specific_1_1matrix__product__template.html", null ]
      ] ],
      [ "viennacl::device_specific::template_base_impl< reduction_template, reduction_parameters >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
        [ "viennacl::device_specific::reduction_template", "classviennacl_1_1device__specific_1_1reduction__template.html", null ]
      ] ],
      [ "viennacl::device_specific::template_base_impl< row_wise_reduction_template, row_wise_reduction_parameters >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
        [ "viennacl::device_specific::row_wise_reduction_template", "classviennacl_1_1device__specific_1_1row__wise__reduction__template.html", null ]
      ] ],
      [ "viennacl::device_specific::template_base_impl< vector_axpy_template, vector_axpy_parameters >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
        [ "viennacl::device_specific::vector_axpy_template", "classviennacl_1_1device__specific_1_1vector__axpy__template.html", null ]
      ] ],
      [ "viennacl::device_specific::template_base_impl< TemplateType, ParametersType >", "classviennacl_1_1device__specific_1_1template__base__impl.html", null ]
    ] ],
    [ "testData", "structtest_data.html", null ],
    [ "viennacl::tools::timer", "classviennacl_1_1tools_1_1timer.html", null ],
    [ "Timer", "class_timer.html", null ],
    [ "viennacl::toeplitz_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1toeplitz__matrix.html", null ],
    [ "viennacl::toeplitz_matrix< NumericT, AlignmentV >", "classviennacl_1_1toeplitz__matrix.html", null ],
    [ "viennacl::device_specific::tree_parsing::traversal_functor", "classviennacl_1_1device__specific_1_1tree__parsing_1_1traversal__functor.html", [
      [ "viennacl::device_specific::tree_parsing::evaluate_expression_traversal", "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html", null ],
      [ "viennacl::device_specific::tree_parsing::filter", "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html", null ],
      [ "viennacl::device_specific::tree_parsing::filter_elements", "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter__elements.html", null ],
      [ "viennacl::device_specific::tree_parsing::process_traversal", "classviennacl_1_1device__specific_1_1tree__parsing_1_1process__traversal.html", null ],
      [ "viennacl::device_specific::tree_parsing::statement_representation_functor", "classviennacl_1_1device__specific_1_1tree__parsing_1_1statement__representation__functor.html", null ]
    ] ],
    [ "viennacl::device_specific::builtin_database::database_type< ParamT >::type", "structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1type.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< T >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string.html", null ],
    [ "viennacl::ocl::type_to_string< T >", "structviennacl_1_1ocl_1_1type__to__string.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< char >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01char_01_4.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< double >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01double_01_4.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< float >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01float_01_4.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< int >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01int_01_4.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< long >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01long_01_4.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< short >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01short_01_4.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< unsigned char >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01char_01_4.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< unsigned int >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01int_01_4.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< unsigned long >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01long_01_4.html", null ],
    [ "viennacl::device_specific::utils::type_to_string< unsigned short >", "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01short_01_4.html", null ],
    [ "viennacl::linalg::cuda::detail::type_to_type2< NumericT >", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2.html", null ],
    [ "viennacl::linalg::cuda::detail::type_to_type2< double >", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01double_01_4.html", null ],
    [ "viennacl::linalg::cuda::detail::type_to_type2< float >", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01float_01_4.html", null ],
    [ "viennacl::backend::typesafe_host_array< T, special >", "classviennacl_1_1backend_1_1typesafe__host__array.html", null ],
    [ "viennacl::backend::typesafe_host_array< T, true >", "classviennacl_1_1backend_1_1typesafe__host__array_3_01_t_00_01true_01_4.html", null ],
    [ "viennacl::linalg::unit_lower_tag", "structviennacl_1_1linalg_1_1unit__lower__tag.html", null ],
    [ "viennacl::linalg::unit_upper_tag", "structviennacl_1_1linalg_1_1unit__upper__tag.html", null ],
    [ "viennacl::linalg::upper_tag", "structviennacl_1_1linalg_1_1upper__tag.html", null ],
    [ "viennacl::result_of::value_type< T >", "structviennacl_1_1result__of_1_1value__type.html", null ],
    [ "viennacl::vandermonde_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1vandermonde__matrix.html", null ],
    [ "viennacl::linalg::opencl::kernels::vector< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html", null ],
    [ "viennacl::linalg::host_based::detail::vector_array_wrapper< NumericT >", "classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html", null ],
    [ "viennacl::vector_base< NumericT, SizeT, DistanceT >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< char >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< double >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< float >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< int >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< long >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< NumericT >", "classviennacl_1_1vector__base.html", [
      [ "viennacl::vector< NumericT >", "classviennacl_1_1vector.html", null ],
      [ "viennacl::vector< NumericT, AlignmentV >", "classviennacl_1_1vector.html", null ],
      [ "viennacl::vector< NumericType >", "classviennacl_1_1vector.html", null ],
      [ "viennacl::vector< ScalarType >", "classviennacl_1_1vector.html", null ],
      [ "viennacl::vector< unsigned int >", "classviennacl_1_1vector.html", null ],
      [ "viennacl::vector< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1vector.html", null ]
    ] ],
    [ "viennacl::vector_base< short >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< unsigned char >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< unsigned int >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< unsigned long >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< unsigned short >", "classviennacl_1_1vector__base.html", null ],
    [ "viennacl::vector_base< VectorType::cpu_value_type >", "classviennacl_1_1vector__base.html", [
      [ "viennacl::vector_range< VectorType >", "classviennacl_1_1vector__range.html", null ],
      [ "viennacl::vector_range< vector_range< VectorType > >", "classviennacl_1_1vector__range_3_01vector__range_3_01_vector_type_01_4_01_4.html", null ],
      [ "viennacl::vector_slice< VectorType >", "classviennacl_1_1vector__slice.html", null ],
      [ "viennacl::vector_slice< vector_slice< VectorType > >", "classviennacl_1_1vector__slice_3_01vector__slice_3_01_vector_type_01_4_01_4.html", null ]
    ] ],
    [ "viennacl::linalg::opencl::kernels::vector_element< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__element.html", null ],
    [ "viennacl::vector_expression< LHS, RHS, OP >", "classviennacl_1_1vector__expression.html", null ],
    [ "viennacl::linalg::opencl::kernels::vector_multi_inner_prod< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html", null ],
    [ "vector_proxy< NumericT >", "classvector__proxy.html", null ],
    [ "viennacl::vector_tuple< ScalarT >", "classviennacl_1_1vector__tuple.html", null ],
    [ "ViennaCLBackend_impl", "struct_vienna_c_l_backend__impl.html", null ],
    [ "ViennaCLCUDABackend_impl", "struct_vienna_c_l_c_u_d_a_backend__impl.html", null ],
    [ "ViennaCLHostBackend_impl", "struct_vienna_c_l_host_backend__impl.html", null ],
    [ "ViennaCLHostScalar_impl", "struct_vienna_c_l_host_scalar__impl.html", null ],
    [ "ViennaCLMatrix_impl", "struct_vienna_c_l_matrix__impl.html", null ],
    [ "ViennaCLOpenCLBackend_impl", "struct_vienna_c_l_open_c_l_backend__impl.html", null ],
    [ "ViennaCLScalar_impl", "struct_vienna_c_l_scalar__impl.html", null ],
    [ "ViennaCLVector_impl", "struct_vienna_c_l_vector__impl.html", null ],
    [ "viennacl::linalg::detail::z_handler< VectorT, PreconditionerT >", "classviennacl_1_1linalg_1_1detail_1_1z__handler.html", null ],
    [ "viennacl::linalg::detail::z_handler< VectorT, viennacl::linalg::no_precond >", "classviennacl_1_1linalg_1_1detail_1_1z__handler_3_01_vector_t_00_01viennacl_1_1linalg_1_1no__precond_01_4.html", null ]
];